export var bar = {};
class Foo {
    constructor(){
        bar;
    }
}
